@@ -24,8 +24,8 @@ PrefQuiz::PrefQuiz(QWidget *parent) : QWidget(parent)
 {
   setupUi(this);
 
-  connect(kcfg_AutoFlip, SIGNAL(toggled(bool)), kcfg_FlipDelay, SLOT(setEnabled(bool)));
-  connect(kcfg_AutoFlip, SIGNAL(toggled(bool)), kcfg_KeepDiscard, SLOT(setEnabled(bool)));
+  connect(kcfg_AutoFlip, &QAbstractButton::toggled, kcfg_FlipDelay, &QWidget::setEnabled);
+  connect(kcfg_AutoFlip, &QAbstractButton::toggled, kcfg_KeepDiscard, &QWidget::setEnabled);
 
   kcfg_FlipDelay -> setEnabled(kcfg_AutoFlip->isChecked());
   kcfg_KeepDiscard->setEnabled(kcfg_AutoFlip->isChecked());
